import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface TeamSettingsConfig extends cdktf.TerraformMetaArguments {
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/github/r/team_settings#id TeamSettings#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * ID or slug of team
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/github/r/team_settings#team_id TeamSettings#team_id}
    */
    readonly teamId: string;
    /**
    * review_request_delegation block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/github/r/team_settings#review_request_delegation TeamSettings#review_request_delegation}
    */
    readonly reviewRequestDelegation?: TeamSettingsReviewRequestDelegation;
}
export interface TeamSettingsReviewRequestDelegation {
    /**
    * Algorithm to use when determining team members to be assigned to a pull request. Allowed values are ROUND_ROBIN and LOAD_BALANCE
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/github/r/team_settings#algorithm TeamSettings#algorithm}
    */
    readonly algorithm?: string;
    /**
    * The number of reviewers to be assigned to a pull request from this team
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/github/r/team_settings#member_count TeamSettings#member_count}
    */
    readonly memberCount?: number;
    /**
    * Notify the entire team when a pull request is assigned to a member of the team
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/github/r/team_settings#notify TeamSettings#notify}
    */
    readonly notify?: boolean | cdktf.IResolvable;
}
export declare function teamSettingsReviewRequestDelegationToTerraform(struct?: TeamSettingsReviewRequestDelegationOutputReference | TeamSettingsReviewRequestDelegation): any;
export declare class TeamSettingsReviewRequestDelegationOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): TeamSettingsReviewRequestDelegation | undefined;
    set internalValue(value: TeamSettingsReviewRequestDelegation | undefined);
    private _algorithm?;
    get algorithm(): string;
    set algorithm(value: string);
    resetAlgorithm(): void;
    get algorithmInput(): string | undefined;
    private _memberCount?;
    get memberCount(): number;
    set memberCount(value: number);
    resetMemberCount(): void;
    get memberCountInput(): number | undefined;
    private _notify?;
    get notify(): boolean | cdktf.IResolvable;
    set notify(value: boolean | cdktf.IResolvable);
    resetNotify(): void;
    get notifyInput(): boolean | cdktf.IResolvable | undefined;
}
/**
* Represents a {@link https://www.terraform.io/docs/providers/github/r/team_settings github_team_settings}
*/
export declare class TeamSettings extends cdktf.TerraformResource {
    static readonly tfResourceType = "github_team_settings";
    /**
    * Create a new {@link https://www.terraform.io/docs/providers/github/r/team_settings github_team_settings} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options TeamSettingsConfig
    */
    constructor(scope: Construct, id: string, config: TeamSettingsConfig);
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _teamId?;
    get teamId(): string;
    set teamId(value: string);
    get teamIdInput(): string | undefined;
    get teamSlug(): string;
    get teamUid(): string;
    private _reviewRequestDelegation;
    get reviewRequestDelegation(): TeamSettingsReviewRequestDelegationOutputReference;
    putReviewRequestDelegation(value: TeamSettingsReviewRequestDelegation): void;
    resetReviewRequestDelegation(): void;
    get reviewRequestDelegationInput(): TeamSettingsReviewRequestDelegation | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
